@@ -1,4 +1,4 @@
-/* GDM - The Gnome Display Manager
+/* GDM - The GNOME Display Manager
  * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * support other XAuth types and possibly DECnet... */
 
 #include <config.h>
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <unistd.h>
@@ -69,7 +69,7 @@ display_add_error (GdmDisplay *d)
 		gdm_error (_("%s: Could not write new authorization entry.  "
 			     "Possibly out of diskspace"),
 			   "add_auth_entry");
-	if (d->console) {
+	if (d->attached) {
 		char *s = g_strdup_printf
 			(C_(N_("GDM could not write a new authorization "
 			       "entry to disk.  Possibly out of diskspace.%s%s")),
