@@ -1,4 +1,4 @@
-/* GDM - The Gnome Display Manager
+/* GDM - The GNOME Display Manager
  * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * and the user's session scripts. */
 
 #include <config.h>
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <unistd.h>
@@ -51,6 +51,7 @@ extern char *stored_path;
 extern gchar *GdmUser;
 extern gchar *GdmServAuthDir;
 extern gchar *GdmGtkRC;
+extern gchar *GdmGtkTheme;
 extern uid_t GdmUserId;
 extern gid_t GdmGroupId;
 extern gboolean GdmAddGtkModules;
@@ -262,10 +263,28 @@ setup_dialog (GdmDisplay *d, const char *name, int closefdexcept, gboolean set_g
 
 	gtk_init (&argc, &argv);
 
-	if( ! inhibit_gtk_themes &&
-	    ! ve_string_empty (GdmGtkRC) &&
-	   access (GdmGtkRC, R_OK) == 0)
-		gtk_rc_parse (GdmGtkRC);
+	if ( ! inhibit_gtk_themes) {
+		const char *theme_name;
+
+		if ( ! ve_string_empty (GdmGtkRC) &&
+		     access (GdmGtkRC, R_OK) == 0)
+			gtk_rc_parse (GdmGtkRC);
+
+		theme_name = d->theme_name;
+		if (ve_string_empty (theme_name))
+			theme_name = GdmGtkTheme;
+		if ( ! ve_string_empty (theme_name)) {
+			gchar *theme_dir = gtk_rc_get_theme_dir ();
+			char *theme = g_strdup_printf ("%s/%s/gtk-2.0/gtkrc", theme_dir, theme_name);
+			g_free (theme_dir);
+
+			if ( ! ve_string_empty (theme) &&
+			     access (theme, R_OK) == 0)
+				gtk_rc_parse (theme);
+
+			g_free (theme);
+		}
+	}
 
 	get_screen_size (d);
 }
@@ -349,13 +368,14 @@ gdm_error_box_full (GdmDisplay *d, GtkMessageType type, const char *error,
 						valid_utf8 = FALSE;
 					g_string_append (gs, buf);
 					/* cap the lines at 500, that's already
-					   a possibility of 128k of crap */
+					   a possibility of 128k of data */
 					if (lines ++ > 500) {
 						loc = gdm_locale_to_utf8 (_("\n... File too long to display ...\n"));
 						g_string_append (gs, loc);
 						g_free (loc);
 						break;
 					}
+					VE_IGNORE_EINTR (getsret = fgets (buf, sizeof (buf), fp));
 				}
 				VE_IGNORE_EINTR (fclose (fp));
 			} else {
