@@ -1,3 +1,21 @@
+/* GDM - The GNOME Display Manager
+ * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
 #include "config.h"
 
 #include <libgnome/libgnome.h>
@@ -24,7 +42,7 @@ enum {
 
 static GtkListStore *lang_model = NULL;
 static GtkWidget *dialog = NULL;
-static gboolean savelang = FALSE;
+static gint savelang = GTK_RESPONSE_NO;
 static gchar *current_language = NULL;
 static gchar *dialog_selected_language = NULL;
 
@@ -86,7 +104,7 @@ greeter_langauge_initialize_model (void)
   g_list_free (list);
 }
 
-gboolean
+gint
 greeter_language_get_save_language (void)
 {
   return savelang;
@@ -98,7 +116,7 @@ greeter_language_get_language (const char *old_language)
   gchar *retval = NULL;
 
   /* Don't save language unless told otherwise */
-  savelang = FALSE;
+  savelang = GTK_RESPONSE_NO;
 
   if (old_language == NULL)
     old_language = "";
@@ -140,7 +158,7 @@ greeter_language_get_language (const char *old_language)
 	  g_free (current_name);
 	  g_free (saved_name);
 
-	  savelang = gdm_common_query (msg, TRUE /* markup */, _("Make _Default"), _("Just For _This Session"));
+	  savelang = gdm_common_query (msg, TRUE /* markup */, _("Make _Default"), _("Just For _This Session"), TRUE);
 	  g_free (msg);
 	}
     }
